@@ -6,7 +6,7 @@ class APIInterface:
         self.API_Key = API
     
     def send_request(self, message):
-        response = requests.post("https://URL/chat", headers={
+        response = requests.post("https://timewiserobot.com", headers={
             "API-Key": f"{self.API_Key}"
             }, data=json.dumps({
             "query": f"{message}"
